@@ -1,5 +1,9 @@
+import io
+
+import xlsxwriter
 from fastapi import Depends, APIRouter
 from fastapi.responses import UJSONResponse
+from starlette.responses import StreamingResponse
 from starlette.status import HTTP_409_CONFLICT
 from tortoise import Model
 from tortoise.contrib.pydantic import pydantic_model_creator
@@ -17,6 +21,39 @@ from ..shortcuts import get_object_or_404
 router = APIRouter()
 
 
+@router.get(
+    '/{resource}/export'
+)
+async def export(
+        resource: str,
+        query: QueryItem = Depends(get_query),
+        model=Depends(get_model)
+):
+    qs = model.all()
+    if query.where:
+        qs = qs.filter(**query.where)
+    resource = await app.get_resource(resource)
+    result = await qs
+    creator = pydantic_model_creator(model, include=resource.resource_fields.keys(), exclude=model._meta.m2m_fields)
+    data = map(lambda x: creator.from_orm(x).dict(), result)
+
+    output = io.BytesIO()
+    workbook = xlsxwriter.Workbook(output)
+    worksheet = workbook.add_worksheet()
+    for row, item in enumerate(data):
+        col = 0
+        for k, v in item.items():
+            if row == 0:
+                worksheet.write(row, col, k)
+            worksheet.write(row + 1, col, v)
+            col += 1
+
+    workbook.close()
+    output.seek(0)
+
+    return StreamingResponse(output)
+
+
 @router.get(
     '/{resource}',
     dependencies=[Depends(read_checker)]
