@@ -8,15 +8,6 @@ from ..factory import app
 router = APIRouter()
 
 
-@router.get(
-    '/home',
-)
-async def home():
-    return {
-        'title': "Welcome to FastAPI ADMIN"
-    }
-
-
 @router.get(
     '/site',
 )
